/********************************************************
* COS265 Data Structures & Algorithms                   *
* Project 4 - Pathfinding                               *
* by Chad Jordan 11/05/07                               *
*                                                       *
* Java implementation that allows the user to set a     *
* start point and an end point by clicking inside the   *
* visualizer window.                                    *
* Dependencies: PathfinderVisualizer.java               *
********************************************************/
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.awt.geom.Point2D;

public class PathfinderInteractive {

    public static void main(String[] args) {
        int[][] heightMap = {
                {10, 20, 30, 40},
                {15, 25, 35, 45},
                {20, 30, 40, 50},
                {25, 35, 45, 55}
        };
        Terrain terrain = new Terrain(heightMap);

        AStarPathfinder pathfinder = new AStarPathfinder(); 
        Walker walker = new Walker(new Point2D.Double(0, 0), new Point2D.Double(3, 3)); 

        PathfinderVisualizer visualizer = new PathfinderVisualizer(terrain, pathfinder, walker);
        visualizer.addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent e) {
                Point2D.Double clickedPoint = new Point2D.Double(e.getX() / 10.0, e.getY() / 10.0);
                if (walker.getCurrentPosition() == null) {
                    walker.setCurrentPosition(clickedPoint);
                } else if (walker.getDestination() == null) {
                    walker.setDestination(clickedPoint);
                    walker.findPath();
                    visualizer.repaint();
                }
            }
        });

        JFrame frame = new JFrame("Pathfinder Interactive");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.getContentPane().add(visualizer);
        frame.pack();
        frame.setLocationRelativeTo(null);
        frame.setVisible(true);
    }
}
