/****************************************************************
* COS265 Data Structures & Algorithms                           *
* Project 4 - Pathfinding                                       *
* by Chad Jordan 11/05/07                                       *
*                                                               *
* Java implementation for a class renderer designed as a        *
* path visualizer. No specifications have been provided for     *
* the grid size, so this program assumes the grid is 10x10      *
* pixels. Jpanel is used to create a custom component for       *
* rendering the terrain, path, and walker.                      *
* Dependencies: Terrain.java, Pathfinder.java, & Walker.java    *
****************************************************************/
import java.awt.*;
import java.awt.geom.Point2D;
import javax.swing.*;

public class Renderer extends JPanel {

    private Terrain terrain;
    private Pathfinder pathfinder;
    private Walker walker;

    public Renderer(Terrain terrain, Pathfinder pathfinder, Walker walker) {
        this.terrain = terrain;
        this.pathfinder = pathfinder;
        this.walker = walker;

        setPreferredSize(new Dimension(800, 600));
    }

    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);
        Graphics2D g2d = (Graphics2D) g;

        // Render terrain
        renderTerrain(g2d);

        // Render path
        renderPath(g2d);

        // Render walker
        renderWalker(g2d);
    }

    //Assuming each grid is 10x10 pixels
    private void renderTerrain(Graphics2D g2d) {
        g2d.setColor(Color.LIGHT_GRAY);
        for (int i = 0; i < terrain.getHeightMap().length; i++) {
            for (int j = 0; j < terrain.getHeightMap()[0].length; j++) {
                int height = terrain.getHeightMap()[i][j];
                g2d.fillRect(i * 10, j * 10, 10, 10); 
            }
        }
    }

    //Assuming each grid is 10x10 pixels, then rendering path points as small circles
    private void renderPath(Graphics2D g2d) {
        if (pathfinder != null && !pathfinder.getPath().isEmpty()) {
            g2d.setColor(Color.BLUE);
            for (Point2D.Double point : pathfinder.getPath()) {
                int x = (int) (point.getX() * 10); 
                int y = (int) (point.getY() * 10); 
                g2d.fillOval(x, y, 5, 5); 
            }
        }
    }

    //Assuming each grid is 10x10 pixels, then rendering larger walker
    private void renderWalker(Graphics2D g2d) {
        if (walker != null) {
            g2d.setColor(Color.RED);
            int x = (int) (walker.getCurrentPosition().getX() * 10);
            int y = (int) (walker.getCurrentPosition().getY() * 10);
            g2d.fillOval(x, y, 10, 10);
        }
    }

    public static void main(String[] args) {
        int[][] heightMap = {
                {10, 20, 30, 40},
                {15, 25, 35, 45},
                {20, 30, 40, 50},
                {25, 35, 45, 55}
        };
        Terrain terrain = new Terrain(heightMap);

        Pathfinder pathfinder = new AStarPathfinder(); 
        Walker walker = new Walker(new Point2D.Double(0, 0), new Point2D.Double(3, 3)); 

        Renderer renderer = new Renderer(terrain, pathfinder, walker);

        JFrame frame = new JFrame("Renderer");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.getContentPane().add(renderer);
        frame.pack();
        frame.setLocationRelativeTo(null);
        frame.setVisible(true);
    }
}