/****************************************************
* COS265 Data Structures & Algorithms               *
* Project 4 - Pathfinding                           *
* by Chad Jordan 11/05/07                           *
*                                                   *
* Java implementation for a basic terrain class     *
* dependencies: none                                *
****************************************************/
import java.awt.geom.Point2D;

public class Terrain {

    private int[][] heightMap; // Assuming a 2D array to represent the terrain height map

    public Terrain(int[][] heightMap) {
        this.heightMap = heightMap;
    }

    // Compute the "as the crow flies" distance between two points
    public double computeDistance(Point2D.Double point1, Point2D.Double point2) {
        double dx = point2.getX() - point1.getX();
        double dy = point2.getY() - point1.getY();
        return Math.sqrt(dx * dx + dy * dy);
    }

    // Compute the travel cost from the first point to the second point
    public double computeTravelCost(Point2D.Double point1, Point2D.Double point2) {
        double distance = computeDistance(point1, point2);
        int heightDifference = Math.abs(heightMap[(int) point2.getX()][(int) point2.getY()] -
                                         heightMap[(int) point1.getX()][(int) point1.getY()]);
        return distance + heightDifference;
    }

    public static void main(String[] args) {
        // Example usage of Terrain class
        int[][] heightMap = {
                {10, 20, 30, 40},
                {15, 25, 35, 45},
                {20, 30, 40, 50},
                {25, 35, 45, 55}
        };
        Terrain terrain = new Terrain(heightMap);

        Point2D.Double point1 = new Point2D.Double(1, 1);
        Point2D.Double point2 = new Point2D.Double(3, 3);

        double distance = terrain.computeDistance(point1, point2);
        System.out.println("Distance between " + point1 + " and " + point2 + ": " + distance);

        double travelCost = terrain.computeTravelCost(point1, point2);
        System.out.println("Travel cost from " + point1 + " to " + point2 + ": " + travelCost);
    }
}
