/************************************************
* COS265 Data Structures & Algorithms           *
* Project 4 - Pathfinding                       *
* by Chad Jordan 11/05/07                       *
*                                               *
* Java implementation of a basic walker         *
* class for a pathfinder from point A to B.     *
* Dependencies: none                            * 
************************************************/
import java.awt.geom.Point2D;
import java.util.ArrayList;
import java.util.List;

public class Walker {

    private Point2D.Double currentPosition;
    private Point2D.Double destination;
    private List<Point2D.Double> path;

    public Walker(Point2D.Double initialPosition, Point2D.Double destination) {
        this.currentPosition = initialPosition;
        this.destination = destination;
        this.path = new ArrayList<>();
    }

    public void walk(Pathfinder pathfinder) {
        path = pathfinder.findPath(currentPosition, destination);
        if (!path.isEmpty()) {
            currentPosition = path.get(0);
            path.remove(0);
        }
    }

    public Point2D.Double getCurrentPosition() {
        return currentPosition;
    }

    public Point2D.Double getDestination() {
        return destination;
    }

    public List<Point2D.Double> getPath() {
        return path;
    }

    public static void main(String[] args) {
        Point2D.Double initialPosition = new Point2D.Double(0, 0);
        Point2D.Double destination = new Point2D.Double(10, 10);

        Pathfinder pathfinder = new AStarPathfinder(); // Replace with your actual pathfinder implementation
        Walker walker = new Walker(initialPosition, destination);

        // Perform walking until destination is reached
        while (!walker.getCurrentPosition().equals(walker.getDestination())) {
            walker.walk(pathfinder);
            System.out.println("Current position: " + walker.getCurrentPosition());
        }

        System.out.println("Destination reached!");
    }
}